@@ -27,6 +27,7 @@ type coercing.
 """
 
 import re
+import socket
 import inspect
 from pysnmp.entity.rfc3413.oneliner import cmdgen
 from pysnmp.proto import rfc1902, rfc1905
@@ -154,10 +155,39 @@ class Session(object):
             raise ValueError("unsupported SNMP version {0}".format(version))
 
         # Put transport stuff into self._transport
-        host, port = host.partition(":")[::2]
-        if not port:
+        mo = re.match(r'^(?:'
+                      r'\[(?P<ipv6>[\d:]+)\]|'
+                      r'(?P<ipv4>[\d\.]+)|'
+                      r'(?P<any>.*?))'
+                      r'(?::(?P<port>\d+))?$',
+                      host)
+        if mo.group("port"):
+            port = int(mo.group("port"))
+        else:
             port = 161
-        self._transport = cmdgen.UdpTransportTarget((host, int(port)))
+        if mo.group("ipv6"):
+            self._transport = cmdgen.Udp6TransportTarget((mo.group("ipv6"),
+                                                          port))
+        elif mo.group("ipv4"):
+            self._transport = cmdgen.UdpTransportTarget((mo.group("ipv4"),
+                                                         port))
+        else:
+            results = socket.getaddrinfo(mo.group("any"),
+                                         port,
+                                         0,
+                                         socket.SOCK_DGRAM,
+                                         socket.IPPROTO_UDP)
+            # We should try to connect to each result to determine if
+            # the given family is available. However, we cannot do
+            # that over UDP. Let's implement a safe choice. If we have
+            # an IPv4 address, use that. If not, use IPv6. If we want
+            # to add an option to force IPv6, it is a good place.
+            if [x for x in results if x[0] == socket.AF_INET]:
+                self._transport = cmdgen.UdpTransportTarget((mo.group("any"),
+                                                             port))
+            else:
+                self._transport = cmdgen.Udp6TransportTarget((mo.group("any"),
+                                                              port))
 
         # Bulk stuff
         self.bulk = 40
