@@ -1,11 +1,15 @@
 import unittest
 import os
 import tempfile
+import code  # nopep8
+import mock
 from snimpy.main import interact
 from multiprocessing import Process
 import agent
 
+
 class TestMain(unittest.TestCase):
+
     """Test the main shell"""
 
     @classmethod
@@ -21,15 +25,16 @@ class TestMain(unittest.TestCase):
         try:
             script.write("""
 load("IF-MIB")
-m = M(host="127.0.0.1:%d",
+m = M(host="127.0.0.1:{0}",
       community="public",
       version=2)
 assert(m.ifDescr[1] == "lo")
-""" % self.agent.port)
+""".format(self.agent.port).encode("ascii"))
             script.close()
-            p = Process(target=interact, args=((script.name,),))
-            p.start()
-            p.join()
-            self.assertEqual(p.exitcode, 0)
+            with mock.patch("code.InteractiveInterpreter.write"):
+                p = Process(target=interact, args=((script.name,),))
+                p.start()
+                p.join()
+                self.assertEqual(p.exitcode, 0)
         finally:
             os.unlink(script.name)
